function X=gengcp(kappan,kappag,mu,dsdt)
%The potential for the geometric Cauchy problem 
%See "Spherical Surfaces" by David Brander http://arxiv.org/pdf/1506.01605.pdf
%Theorem 4.4

%Input: kappan, kappag and mu are (real analytic) function handles for
%functions of 1 variable. If the curve is not unit speed, then the 
%speed of the curve, dsdt needs to be included as well

if nargin<4
    dsdt=@(t)1;
end
X=@(z,h)(1/4)*dsdt(z)*...
    [0,  -1i*mu(z)+1-kappan(z),  2*kappag(z)*1i ,      -1i*mu(z)-1-kappan(z),        0,               0;...
     0,     0,                  -1i*mu(z)+1+kappan(z), -2*kappag(z)*1i ,       -1i*mu(z)-1+kappan(z), 0];
end